import { makeAutoObservable, runInAction } from "mobx";
import api, { MessageRecordDto } from "@dashboard/engine-api";
import displayError from "@dashboard/utils/displayError";

class BasicMessageListStore {
  public loading = false;
  public sendingMessage = false;
  public items: MessageRecordDto[] = [];
  constructor() {
    makeAutoObservable(this);
  }

  public async loadAll(connectionId: string | null) {
    runInAction(() => (this.loading = true));
    try {
      const items = await api.fetchBasicMessages(
        undefined,
        connectionId || undefined,
      );
      runInAction(() => {
        this.items = items;
        this.loading = false;
      });
    } catch (e: unknown) {
      displayError(e);
      runInAction(() => (this.loading = false));
    }
  }

  public sendMessage = async (connectionId: string, content: string) => {
    runInAction(() => (this.sendingMessage = true));
    try {
      const message = await api.sendMessage({
        connectionId: connectionId,
        message: content,
      });
      runInAction(() => {
        this.items.push(message);
        this.sendingMessage = false;
      });
      return true;
    } catch (e: unknown) {
      displayError(e);
      runInAction(() => (this.sendingMessage = false));
    }
    return false;
  };
}

export type { BasicMessageListStore };

export default BasicMessageListStore;
