import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Spin } from "antd";
import CredentialItem from "@dashboard/components/CredentialItem";
import CredentialListStore from "./CredentialListStore";
import NoRecordsMessage from "../NoRecordsMessage";
import modalStore from "@dashboard/store/modalStore";

export interface CredentialListProps {
  connectionId: string | null;
}

const CredentialList: React.FC<CredentialListProps> = observer(
  ({ connectionId }) => {
    const [store] = useState(() => new CredentialListStore());

    useEffect(() => {
      store.loadAll(connectionId);
    }, [store, connectionId]);

    const handleDelete = async (credId: string) => {
      modalStore.openConfirmDialog({
        title: "Are you sure you want to delete this credential record?",
        description: "",
        dangerOk: true,
        onOk: async (e) => {
          await store.remove(credId);
          e.close();
        },
      });
    };

    const handleDecline = async (credId: string) => {
      modalStore.openConfirmDialog({
        title: "Are you sure you want to decline this credential offer?",
        description: "",
        dangerOk: true,
        onOk: async (e) => {
          await store.decline(credId);
          e.close();
        },
      });
    };

    return (
      <div>
        {store.items.map((p) => (
          <CredentialItem
            key={p.id}
            item={p}
            onAccept={() => store.accept(p.id!)}
            onDecline={() => handleDecline(p.id!)}
            statusChanging={store.statusChangeId === p.id}
            onRemove={() => handleDelete(p.id!)}
          />
        ))}
        {!store.loading && !store.items.length && <NoRecordsMessage />}
        {store.loading && <Spin />}
      </div>
    );
  },
);

export default CredentialList;
