import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Form, Input, Button } from "antd";
import api, { CredentialRecordDto } from "@dashboard/engine-api";
import { toast } from "react-toastify";
import Modal, { FcProps } from "@dashboard/components/Modal";
import s from "./styles.module.scss";
import displayError from "@dashboard/utils/displayError";

export interface AcceptConnectionlessCredentialOfferDialogProps {
  onCredentialReceived: (credentialRecord: CredentialRecordDto) => void;
}

const AcceptConnectionlessCredentialOfferDialog = observer(
  ({
    setTitle,
    onClose,
    data,
  }: FcProps<AcceptConnectionlessCredentialOfferDialogProps>) => {
    useEffect(() => {
      setTitle("Accept credential by URL");
    }, [setTitle]);

    const [loading, setLoading] = useState(false);

    const onFinish = async ({ credentialUrl }: { credentialUrl: string }) => {
      try {
        setLoading(true);
        const credentialRecord = await api.acceptCredential({
          credentialUrl,
          credentialId: "",
        });

        if (credentialRecord) {
          toast.success(`Credential offer accepted`);
          data.onCredentialReceived(credentialRecord);
          onClose();
        }
      } catch (e: unknown) {
        displayError(e);
      }
      setLoading(false);
    };

    return (
      <Modal.Body>
        <div className={s.body}>
          <Form
            layout="vertical"
            initialValues={{
              credentialUrl: "",
            }}
            onFinish={onFinish}
            autoComplete="off"
          >
            <Form.Item
              label="credential url"
              name="credentialUrl"
              rules={[
                { required: true, message: "Please enter credential url!" },
              ]}
            >
              <Input.TextArea rows={12} />
            </Form.Item>

            <div className={s.footerActions}>
              <Button type="primary" htmlType="submit" disabled={loading}>
                Accept Offer
              </Button>
              <Button
                className={s.cancelButton}
                onClick={onClose}
                disabled={loading}
              >
                Close
              </Button>
            </div>
          </Form>
        </div>
      </Modal.Body>
    );
  },
);

export default AcceptConnectionlessCredentialOfferDialog;
