import React from "react";
import { Button, Form, Input, Space } from "antd";
import { LegalParticipantFormData } from "../interfaces";

export interface LegalParticipantFormProps {
  loading: boolean;
  onSendOffer: (values: LegalParticipantFormData) => void;
}

const LegalParticipantForm = ({
  loading,
  onSendOffer,
}: LegalParticipantFormProps) => {
  const initialValue: LegalParticipantFormData = {
    companyName: "",
    taxID: "",
    gleiCode: "",
    street: "",
    building: "",
    city: "",
    country: "",
  };
  return (
    <div>
      <Form
        layout="vertical"
        initialValues={initialValue}
        onFinish={onSendOffer}
        autoComplete="off"
      >
        <Form.Item
          label="CompanyName"
          name="companyName"
          rules={[{ required: true, message: "Please enter companyName!" }]}
        >
          <Input />
        </Form.Item>
        <Form.Item
          label="TaxID"
          name="taxID"
          rules={[{ required: true, message: "Please enter taxID!" }]}
        >
          <Input />
        </Form.Item>
        <Form.Item
          label="GleiCode"
          name="gleiCode"
          rules={[{ required: true, message: "Please enter gleiCode!" }]}
        >
          <Input />
        </Form.Item>
        <Form.Item
          label="Street"
          name="street"
          rules={[{ required: true, message: "Please enter street!" }]}
        >
          <Input />
        </Form.Item>
        <Form.Item
          label="Building"
          name="building"
          rules={[{ required: true, message: "Please enter building!" }]}
        >
          <Input />
        </Form.Item>
        <Form.Item
          label="City"
          name="city"
          rules={[{ required: true, message: "Please enter city!" }]}
        >
          <Input />
        </Form.Item>
        <Form.Item
          label="Country"
          name="country"
          rules={[{ required: true, message: "Please enter country!" }]}
        >
          <Input />
        </Form.Item>

        <Space direction="horizontal">
          <Button
            type="primary"
            htmlType="submit"
            disabled={loading}
            loading={loading}
          >
            Send JSON-LD offer
          </Button>
        </Space>
      </Form>
    </div>
  );
};

export default LegalParticipantForm;
