import React, { useEffect } from "react";
import { observer } from "mobx-react";
import Modal, { FcProps } from "@dashboard/components/Modal";
import { CredentialRecordDto } from "@dashboard/engine-api";
import CredentialItem from "@dashboard/components/CredentialItem";
import { QRCode } from "antd";
import s from "./styles.module.scss";

export interface ViewConnectionlessCredentialOfferProps {
  credentialUrl: string | undefined | null;
  credentialUrlShort: string | undefined | null;
  credentialRecord: CredentialRecordDto;
}

const ViewConnectionlessCredentialOffer = observer(
  ({
    setTitle,
    setWidth,
    setClassName,
    onClose,
    data,
  }: FcProps<ViewConnectionlessCredentialOfferProps>) => {
    useEffect(() => {
      setClassName(s.modal);
      setWidth("80vw");
      setTitle("Connectionless credential offer");
    }, [setClassName, setWidth, setTitle]);

    return (
      <Modal.Body className={s.body}>
        <div className={s.info}>
          <div>
            <div className={s.qrCodeHint}>
              Scan this QR code with mobile wallet
            </div>
            <div className={s.qrWrapper}>
              {data.credentialUrlShort && (
                <QRCode value={data.credentialUrlShort} size={500} />
              )}
            </div>
            <div>
              <div className={s.urlTitle}>Credential offer URL:</div>
              <div className={s.url}>
                <b>{data.credentialUrl}</b>
              </div>
              <div className={s.urlTitle}>Credential offer short URL:</div>
              <div className={s.url}>
                <b>{data.credentialUrlShort}</b>
              </div>
              {data.credentialRecord && (
                <div>
                  Details:
                  <CredentialItem item={data.credentialRecord} />
                </div>
              )}
            </div>
          </div>
        </div>
      </Modal.Body>
    );
  },
);

export default ViewConnectionlessCredentialOffer;
