import React, { useState } from "react";
import { observer } from "mobx-react";
import RegisterPageStore from "./RegisterPageStore";
import { Button, Form, Input, QRCode } from "antd";
import Page from "@dashboard/components/Page";
import VaultHeader from "@dashboard/components/VaultHeader";
import { Link } from "react-router-dom";
import config from "@dashboard/routes/config";
import s from "./styles.module.scss";

const RegisterPage = observer(() => {
  const [store] = useState(() => new RegisterPageStore());

  return (
    <Page>
      <VaultHeader hideTry />
      <div className={s.topSpace} />
      <div className={s.info}>
        <div className={s.subTitle}>
          Welcome to the Organization Credential Manager Registration!
        </div>
        <div>
          Start your journey with us by setting up your digital credentials.
          It's quick, secure, and will streamline your future sign-ins.
        </div>
        <br />
        <div>
          <b>Steps to Get Started:</b>
        </div>

        <ul>
          <li>
            <b>Download Our Wallet App</b>: If you haven't installed our mobile
            wallet application yet,{" "}
            <a href="https://play.google.com/store/apps/details?id=com.vereign.vcm">
              click here
            </a>{" "}
            to download it for Android.
          </li>
          <li>
            <b>Enter Your Details:</b> Fill in the form below with your name.
            This name will be encrypted within your credentials, ensuring your
            privacy and security.
          </li>
          <li>
            <b>Scan the QR Code:</b> Use your mobile device to scan the QR code
            displayed below. This will transfer your credentials directly to
            your digital wallet.
          </li>
        </ul>

        <div>
          Once registered, use your credentials to easily and securely sign in
          to our application. Your digital identity is safe with us.
        </div>
      </div>

      <div className={s.registerForm}>
        <div className={s.formTitle}>Registration</div>
        <Form
          layout="vertical"
          initialValues={{
            name: "",
            id: store.id,
          }}
          onFinish={({ name }) => {
            store.initializeQr(name);
          }}
          autoComplete="off"
        >
          <Form.Item label="internal-id" name="id">
            <Input disabled />
          </Form.Item>
          <Form.Item
            label="Name"
            name="name"
            rules={[{ required: true, message: "Please enter your name" }]}
          >
            <Input />
          </Form.Item>

          <div className={s.footerActions}>
            <Button
              type="primary"
              htmlType="submit"
              disabled={store.loading}
              loading={store.loading}
            >
              Generate QR code
            </Button>
          </div>
        </Form>

        {(store.loading && !store.shortCredentialUrl) ||
          (store.shortCredentialUrl && (
            <div className={s.qrWrapper}>
              <QRCode
                status={
                  !store.shortCredentialUrl || store.loading
                    ? "loading"
                    : "active"
                }
                value={store.shortCredentialUrl || "loading"}
                size={400}
                icon={`${window.BASE_PATH}/assets/Vereign_Logo_ICON_BLACK.png`}
              />
            </div>
          ))}
      </div>

      <div className={s.goToLogin}>
        <Link to={config.login.getLink()}>Go to login</Link>
      </div>
    </Page>
  );
});

export default RegisterPage;
