import { ApiException } from "@dashboard/engine-api";
import { toast } from "react-toastify";

function combine(msg1: undefined | string, msg2: string | string[]) {
  let secondMsg = [];
  if (Array.isArray(msg2)) {
    secondMsg = msg2;
  } else {
    secondMsg.push(msg2);
  }
  return (
    <div>
      {msg1}
      {secondMsg.map((p, index) => (
        <>
          {index === 0 && !!msg1 && <br />}
          {index > 0 && <br />}
          {p}
        </>
      ))}
    </div>
  );
}

const displayError = (e: unknown, msg?: string) => {
  console.error(e);

  if (
    e instanceof ApiException ||
    (e as { isApiException: boolean }).isApiException
  ) {
    const apiExError = e as ApiException;
    let serverResponse: {
      message: string | string[];
      statusCode: number;
    } | null;
    try {
      serverResponse = JSON.parse(apiExError.response);
    } catch (parseError: unknown) {
      console.error("Can not parse the server response");
      toast.error(combine(msg, apiExError.message));
      return;
    }

    if (serverResponse && serverResponse.message) {
      toast.error(combine(msg, serverResponse.message));
    } else {
      toast.error(combine(msg, apiExError.message));
    }
    return;
  }

  if (e instanceof Error) {
    toast.error(combine(msg, e.message));
  } else {
    toast.error(combine(msg, "Unknown error"));
  }
};

export default displayError;
