import {
  Client as TSAClient,
  FileResponse,
  KeysResult,
  LoginInvitationResult,
  LoginRequestBody,
  LoginResult,
  LoginVCResult,
  LoginWithVCRequestBody,
} from "./frontend/tsa_gen";

export * from "./frontend/tsa_gen";

export interface Config {
  tsaUrl: string;
}

let config: Config | null = null;

export const setConfig = (cfg: Config) => (config = cfg);

class ApiClient {
  private _rest!: TSAClient;

  /* rest api methods */

  public loginKeys = (): Promise<KeysResult> => this._rest.loginKeys();
  public healthLiveness = (): Promise<FileResponse> =>
    this._rest.healthLiveness();
  public healthReadiness = (): Promise<FileResponse> =>
    this._rest.healthReadiness();
  public loginLogin = (body: LoginRequestBody): Promise<LoginResult> =>
    this._rest.loginLogin(body);
  public loginLoginWithVC = (
    body: LoginWithVCRequestBody,
  ): Promise<LoginVCResult> => this._rest.loginLoginWithVC(body);
  public loginLoginInvitation = (): Promise<LoginInvitationResult> =>
    this._rest.loginLoginInvitation();

  public initialize() {
    const _config = config as Config;

    this._rest = new TSAClient(_config.tsaUrl, {
      // eslint-disable-next-line @typescript-eslint/ban-ts-comment
      // @ts-ignore
      fetch: this._fetch.bind(this),
    });
    this._rest.jsonParseReviver = this.jsonParseReviver;
  }

  private async _fetch(url: RequestInfo, init?: RequestInit): Promise<unknown> {
    if (!config) {
      throw new Error("ApiClient: Please call setConfig before calling api");
    }

    return fetch(url, init);
  }

  public jsonParseReviver = (key: string, value: unknown): unknown => {
    if (typeof value === "string") {
      const a =
        /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*)?)Z?$/.exec(
          value,
        );
      if (a) {
        return new Date(value);
      }
    }
    return value;
  };
}

export default new ApiClient();
