import { Injectable, Logger } from "@nestjs/common";
import { IRegistrator } from "../IRegistrator";
import { IndyVdrPoolConfig } from "@credo-ts/indy-vdr";
import genesisFile from "./genesis-file";
import axios, { AxiosError } from "axios";
import { ConfigService } from "@nestjs/config";
import { LedgerProviderFailRegistrationError } from "@ocm-engine/dtos";
import { ILedgers } from "@ocm-engine/config";

const NAME = "IDUNION";
const URL = "https://endorser.idunion.org/api/dids";

@Injectable()
export class IdunionProvider implements IRegistrator {
  private readonly logger: Logger = new Logger(IdunionProvider.name);
  private config: ILedgers;
  constructor(private readonly configService: ConfigService) {
    //FIXME: propertly check for null
    this.config = configService.get<ILedgers>("ledgers")!;
  }
  getName = (): string => {
    return NAME;
  };

  register = async (
    unqualifiedIndyDid: string,
    verkey: string,
  ): Promise<string> => {
    const did = `did:indy:idunion:${unqualifiedIndyDid}`;

    this.logger.log(`Trying to register ${did} to idunion`);
    try {
      await axios.post(
        `${URL}?apiKey=${this.config.idUnionApiKey}`,
        {
          role: "ENDORSER",
          did: unqualifiedIndyDid,
          verkey,
        },
        {
          auth: {
            username: this.config.idUnionApiBasicUser,
            password: this.config.idUnionApiBasicPass,
          },
        },
      );

      this.logger.log("Registration successful");
      return did;
    } catch (e) {
      this.logger.log("IDUNION Registration failed");

      if (e instanceof Error || e instanceof AxiosError) {
        throw new LedgerProviderFailRegistrationError(e.message);
      }
      throw new Error("IDUNION registration fail - Reason UNKNOWN");
    }
  };

  getNetworkConf = (): IndyVdrPoolConfig => {
    return {
      genesisTransactions: genesisFile,
      indyNamespace: "idunion",
      isProduction: false,
      connectOnStartup: true,
    };
  };
}
